==> kadu_0.9.2.orig.tar.bz2: kadu-0.9.2/kadu-core/protocols/protocols-aware-object.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "protocols-manager.h"

#include "protocols-aware-object.h"

KADU_AWARE_CLASS(ProtocolsAwareObject)

void ProtocolsAwareObject::notifyProtocolRegistered(ProtocolFactory *protocol)
{
	foreach (ProtocolsAwareObject *object, Objects)
		object->protocolRegistered(protocol);
}

void ProtocolsAwareObject::notifyProtocolUnregistered(ProtocolFactory *protocol)
{
	for (QList<ProtocolsAwareObject *>::iterator i = Objects.begin(); i != Objects.end() ; ++i)
		(*i)->protocolUnregistered(protocol);
}

void ProtocolsAwareObject::triggerAllProtocolsRegistered()
{
	foreach (ProtocolFactory *protocol, ProtocolsManager::instance()->protocolFactories())
		protocolRegistered(protocol);
}

void ProtocolsAwareObject::triggerAllProtocolsUnregistered()
{
	foreach (ProtocolFactory *protocol, ProtocolsManager::instance()->protocolFactories())
		protocolUnregistered(protocol);
}

==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/kadu-core/protocols/protocols-aware-object.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "protocols-manager.h"

#include "protocols-aware-object.h"

KADU_AWARE_CLASS(ProtocolsAwareObject)

void ProtocolsAwareObject::notifyProtocolRegistered(ProtocolFactory *protocol)
{
	foreach (ProtocolsAwareObject *object, Objects)
		object->protocolRegistered(protocol);
}

void ProtocolsAwareObject::notifyProtocolUnregistered(ProtocolFactory *protocol)
{
	for (QList<ProtocolsAwareObject *>::const_iterator i = Objects.constBegin(); i != Objects.constEnd() ; ++i)
		(*i)->protocolUnregistered(protocol);
}

void ProtocolsAwareObject::triggerAllProtocolsRegistered()
{
	foreach (ProtocolFactory *protocol, ProtocolsManager::instance()->protocolFactories())
		protocolRegistered(protocol);
}

void ProtocolsAwareObject::triggerAllProtocolsUnregistered()
{
	foreach (ProtocolFactory *protocol, ProtocolsManager::instance()->protocolFactories())
		protocolUnregistered(protocol);
}
